
/******************************************************************************/
/*  (c)	Copyright Hewlett-Packard Company, 1993,  Fort Collins,	Colorado      */
/*									      */
/*  (C)	COPYRIGHT International	Business Machines Corp.	1993		      */
/*									      */
/*   Copyright (c) 1993	by Sun Microsystems, Inc.			      */
/*									      */
/*			      All Rights Reserved			      */
/*									      */
/*  Permission to use, copy, modify, and distribute this software and its     */
/*  documentation for any purpose and without fee is hereby granted,	      */
/*  provided that the above copyright notices appear in	all copies and that   */
/*  both the copyright notices and this	permission notice appear in	      */
/*  supporting documentation, and that the names of Hewlett-Packard,	      */
/*  International Business Machines, or	Sun Microsystems not be	used in	      */
/*  advertising	or publicity pertaining	to distribution	of the software	      */
/*  without specific, written prior permission.				      */
/*									      */
/*  HEWLETT-PACKARD MAKES NO WARRANTY OF ANY KIND WITH REGARD TO THIS	      */
/*  SOFTWARE, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF	      */
/*  MERCHANTABILITY AND	FITNESS	FOR A PARTICULAR PURPOSE.  Hewlett-Packard    */
/*  shall not be liable	for errors contained herein or direct, indirect,      */
/*  special, incidental	or consequential damages in connection with the	      */
/*  furnishing,	performance or use of this software.			      */
/*									      */
/*  INTERNATIONAL BUSINESS MACHINES CORPORATION	PROVIDES THIS MATERIAL	      */
/*  "AS	IS" WITHOUT WARRANTY OF	ANY KIND, EITHER EXPRESSED OR IMPLIED,	      */
/*  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY  */
/*  AND	FITNESS	FOR A PARTICULAR PURPOSE.				      */
/*									      */
/*  SUN	MICROSYSTEMS, INC. DISCLAIMS ALL WARRANTIES WITH REGARD	TO THIS	      */
/*  SOFTWARE, INCLUDING	ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,*/
/*  IN NO EVENT	SHALL SUN MICROSYSTEMS,	INC. BE	LIABLE FOR ANY SPECIAL,	      */
/*  INDIRECT OR	CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER	RESULTING     */
/*  FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,      */
/*  NEGLIGENCE OR OTHER	TORTIOUS ACTION, ARISING OUT OF	OR IN CONNECTION      */
/*  WITH THE USE OR PERFORMANCE	OF THIS	SOFTWARE.			      */
/*									      */
/******************************************************************************/

/*
===============================================================================
	Common Graphics	Environment (CGE) extensions
	PEX 5.1	Simple Programming Example

	Header file
	Define common function prototypes and data structures

===============================================================================
*/


/*
*******************************************************************************
    This structure is used to describe a view using a
    camera field-of-view model.
*******************************************************************************
*/

typedef	struct
{
    float refx,refy,refz;
    float camx,camy,camz;
    float upx,upy,upz;
    float field_of_view;
    float front,back;
    int	perspective;
} camera_arg;


/*
*******************************************************************************
    This procedure sets	the view table entry to
    the	view described by the camera argument.
*******************************************************************************
*/

extern void set_view_camera(
#if NeedFunctionPrototypes
	Display			*dpy,
	Window			window,
	camera_arg		*ca,
	PEXRenderer		renderer,
	PEXRendererAttributes	*rend_attr,
	int			index
#endif
);


/*
*******************************************************************************
    This procedure generates the geometric model with appropriate
    surface attributes.
*******************************************************************************
*/

extern void Torus(
#if NeedFunctionPrototypes
	Display			*dpy,
	XID			resource_id,
	PEXOCRequestType	req_type
#endif
);


/*
*******************************************************************************
    This procedure creates a structure containing the geometric	model.
*******************************************************************************
*/

extern PEXStructure create_model(
#if NeedFunctionPrototypes
	Display			*dpy
#endif
);


/*
*******************************************************************************
    This procedure sets	up viewing and lighting.
*******************************************************************************
*/

extern void create_scene(
#if NeedFunctionPrototypes
	Display			*dpy,
	camera_arg		*camera,
	int			*num_lights,
	PEXLightEntry		**lights,
	PEXTableIndex		**lss
#endif
);


/*
*******************************************************************************
    This procedure sets	up initial attributes in the Pipeline Context.
*******************************************************************************
*/

extern void create_initial_state(
#if NeedFunctionPrototypes
	Display			*dpy,
	PEXPipelineContext	plc,
	int			num_lights,
	PEXTableIndex		*lss
#endif
);


/*
*******************************************************************************
    This procedure sets	up the Renderer	and creates the	useful
    associated resources (Lookup Tables	and Pipeline Context).
*******************************************************************************
*/

extern PEXRenderer create_renderer(
#if NeedFunctionPrototypes
	Display			*dpy,
	Window			window,
	PEXRendererAttributes	*rend_attrs
#endif
);

